=======
Partner
=======

The partner app mostly provides three abstract models.
:class:`oscar.apps.partner.abstract_models.AbstractPartner` and
:class:`oscar.apps.partner.abstract_models.AbstractStockRecord` are essential
parts of Oscar's catalogue management.

Abstract models
---------------

.. automodule:: oscar.apps.partner.abstract_models
    :members:

Strategy classes
----------------

.. automodule:: oscar.apps.partner.strategy
    :members:

Pricing policies
----------------

.. automodule:: oscar.apps.partner.prices
    :members:

Availability policies
---------------------

.. automodule:: oscar.apps.partner.availability
    :members:
